      SUBROUTINE DGEFA(A,LDA,N,IPVT,INFO)                               
      INTEGER LDA,N,IPVT(1),INFO                                        
      DOUBLE PRECISION A(LDA,1)                                         
C                                                                       
C     dgefa factors a double precision matrix by gaussian elimination.  
C                                                                       
C     dgefa is usually called by dgeco, but it can be called            
C     directly with a saving in time if  rcond  is not needed.          
C     (time for dgeco) = (1 + 9/n)*(time for dgefa) .                   
C                                                                       
C     on entry                                                          
C                                                                       
C        a       double precision(lda, n)                               
C                the matrix to be factored.                             
C                                                                       
C        lda     integer                                                
C                the leading dimension of the array  a .                
C                                                                       
C        n       integer                                                
C                the order of the matrix  a .                           
C                                                                       
C     on return                                                         
C                                                                       
C        a       an upper triangular matrix and the multipliers         
C                which were used to obtain it.                          
C                the factorization can be written  a = l*u  where       
C                l  is a product of permutation and unit lower          
C                triangular matrices and  u  is upper triangular.       
C                                                                       
C        ipvt    integer(n)                                             
C                an integer vector of pivot indices.                    
C                                                                       
C        info    integer                                                
C                = 0  normal value.                                     
C                = k  if  u(k,k) .eq. 0.0 .  this is not an error       
C                     condition for this subroutine, but it does        
C                     indicate that dgesl or dgedi will divide by zero  
C                     if called.  use  rcond  in dgeco for a reliable   
C                     indication of singularity.                        
C                                                                       
C     linpack. this version dated 08/14/78 .                            
C     cleve moler, university of new mexico, argonne national lab.      
C                                                                       
C     subroutines and functions                                         
C                                                                       
C     blas daxpy,dscal,idamax                                           
C                                                                       
C     internal variables                                                
C                                                                       
      DOUBLE PRECISION T                                                
      INTEGER IDAMAX,J,K,KP1,L,NM1                                      
C                                                                       
C                                                                       
C     gaussian elimination with partial pivoting                        
C                                                                       
      INFO = 0                                                          
      NM1 = N - 1                                                       
      IF (NM1 .LT. 1) GO TO 70                                          
      DO 60 K = 1, NM1                                                  
         KP1 = K + 1                                                    
C                                                                       
C        find l = pivot index                                           
C                                                                       
         L = IDAMAX(N-K+1,A(K,K),1) + K - 1                             
         IPVT(K) = L                                                    
C                                                                       
C        zero pivot implies this column already triangularized          
C                                                                       
         IF (A(L,K) .EQ. 0.0D0) GO TO 40                                
C                                                                       
C           interchange if necessary                                    
C                                                                       
            IF (L .EQ. K) GO TO 10                                      
               T = A(L,K)                                               
               A(L,K) = A(K,K)                                          
               A(K,K) = T                                               
   10       CONTINUE                                                    
C                                                                       
C           compute multipliers                                         
C                                                                       
            T = -1.0D0/A(K,K)                                           
            CALL DSCAL(N-K,T,A(K+1,K),1)                                
C                                                                       
C           row elimination with column indexing                        
C                                                                       
            DO 30 J = KP1, N                                            
               T = A(L,J)                                               
               IF (L .EQ. K) GO TO 20                                   
                  A(L,J) = A(K,J)                                       
                  A(K,J) = T                                            
   20          CONTINUE                                                 
               CALL DAXPY(N-K,T,A(K+1,K),1,A(K+1,J),1)                  
   30       CONTINUE                                                    
         GO TO 50                                                       
   40    CONTINUE                                                       
            INFO = K                                                    
   50    CONTINUE                                                       
   60 CONTINUE                                                          
   70 CONTINUE                                                          
      IPVT(N) = N                                                       
      IF (A(N,N) .EQ. 0.0D0) INFO = N                                   
      RETURN                                                            
      END                                                               
